@@ -21,6 +21,7 @@
 #include "bodebug.h"
 
 #include "../boversion.h"
+#include "../boglobal.h"
 #include "../defines.h"
 
 #include <kdeversion.h>
@@ -68,8 +69,7 @@
 #define XEXTLIBGLX_SO "/usr/X11R6/lib/modules/extensions/libglx.so" // proprietary
 #define NVIDIAXDRIVER "/usr/X11R6/lib/modules/drivers/nvidia_drv.o" // proprietary
 
-static KStaticDeleter<BoInfo> sd;
-BoInfo* BoInfo::mBoInfo = 0;
+static BoGlobalObject<BoInfo> globalInfo(BoGlobalObjectBase::BoGlobalInfo);
 
 class BoInfoPrivate
 {
@@ -98,16 +98,9 @@ void BoInfo::init()
  d = new BoInfoPrivate;
 }
 
-void BoInfo::initBoInfo()
-{
- if (!mBoInfo) {
-	sd.setObject(mBoInfo, new BoInfo);
- }
-}
-
 BoInfo* BoInfo::boInfo()
 {
- return mBoInfo;
+ return BoGlobal::boGlobal()->boInfo();
 }
 
 void BoInfo::reset()
@@ -684,6 +677,14 @@ QString BoInfo::valueToString(int key) const
 	case QVariant::CString:
 		string = v.toCString();
 		break;
+#if QT_VERSION >= 0x030200
+	case QVariant::LongLong:
+		string = v.toLongLong();
+		break;
+	case QVariant::ULongLong:
+		string = v.toULongLong();
+		break;
+#endif
  }
  return string;
 }
@@ -786,27 +787,27 @@ QStringList BoInfo::checkProprietaryNVidiaDriver() const
  int ret = getInt(BoInfo::DevNVidiaCTL);
  if (ret != CharSuccess) {
 	QString error = makeCharacterDeviceErrorString(ret);
-	list.append(i18n("Problem with %1: %2").arg("/deb/nvidiactl").arg(error));
+	list.append(i18n("Problem with %1: %2").arg("/dev/nvidiactl").arg(error));
  }
  ret = getInt(BoInfo::DevNVidia0);
  if (ret != CharSuccess) {
 	QString error = makeCharacterDeviceErrorString(ret);
-	list.append(i18n("Problem with %1: %2").arg("/deb/nvidia0").arg(error));
+	list.append(i18n("Problem with %1: %2").arg("/dev/nvidia0").arg(error));
  }
  ret = getInt(BoInfo::DevNVidia1);
  if (ret != CharSuccess) {
 	QString error = makeCharacterDeviceErrorString(ret);
-	list.append(i18n("Problem with %1: %2").arg("/deb/nvidia1").arg(error));
+	list.append(i18n("Problem with %1: %2").arg("/dev/nvidia1").arg(error));
  }
  ret = getInt(BoInfo::DevNVidia2);
  if (ret != CharSuccess) {
 	QString error = makeCharacterDeviceErrorString(ret);
-	list.append(i18n("Problem with %1: %2").arg("/deb/nvidia2").arg(error));
+	list.append(i18n("Problem with %1: %2").arg("/dev/nvidia2").arg(error));
  }
  ret = getInt(BoInfo::DevNVidia3);
  if (ret != CharSuccess) {
 	QString error = makeCharacterDeviceErrorString(ret);
-	list.append(i18n("Problem with %1: %2").arg("/deb/nvidia3").arg(error));
+	list.append(i18n("Problem with %1: %2").arg("/dev/nvidia3").arg(error));
  }
  // TODO: finally the nvcheck.sh script checks for duplicated libGL
  // installations. we should do so as well.
